
# Vennam

Vennam is a Python library for converting Python DataFrame to List of Python Dictionary items .

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Vennam.

```bash
pip install vennam
```

## version

```bash
vennam.__version__ # return current version of Package
```

## Usage

```python
from vennam import DataFrameToDict as dd

list_dict=dd.dftodict(DataFrame) # returns the list of dictionary items

```


## License
[MIT](https://choosealicense.com/licenses/mit/)